@@ -26,6 +26,7 @@
 // declare the private methods
 @interface MusicTab (PrivateAPI)
 - (NSString *)filenameForTrack:(Track *)track;
+- (void)loadiTunesLibrary;
 @end
 
 @implementation MusicTab
@@ -51,6 +52,15 @@
 
 /**********************/
 
+- (void)awakeFromNib
+{
+	[super awakeFromNib];
+	
+	[self setCorrectView];		
+	
+	[njbTable setAllowedExtensions:[self allowedExtensions]];
+}
+
 - (NSString *)browserPathFromPreferences
 {
 	return [preferences musicTabDir];
@@ -60,8 +70,6 @@
 {
 	NSArray *extensions = [NSArray arrayWithObjects:@"mp3", @"wma", @"wav", nil];
 	
-	[njbTable setAllowedExtensions:extensions];
-	
 	return extensions;
 }
 
@@ -144,10 +152,16 @@
 	NSFileManager *manager = [NSFileManager defaultManager];
 	
 	NSString *filename = [self filenameForTrack:track];
-	NSString *directory = [[browser directory] stringByAppendingString:@"/"];
+	NSString *directory = nil;
+	if ([preferences iTunesIntegration])
+		directory = [[[preferences downloadDir] stringByExpandingTildeInPath] stringByAppendingString:@"/"];
+	else
+		directory = [[browser directory] stringByAppendingString:@"/"];
 	
-	NSArray *components = [filename pathComponents];
-	NSMutableString *dirsSoFar = [[NSMutableString alloc] initWithString:directory];
+	NSString *fullPath = [directory stringByAppendingString:filename];
+	
+	NSArray *components = [fullPath pathComponents];
+	NSMutableString *dirsSoFar = [[NSMutableString alloc] initWithString:@"/"];
 	int i = -1;
 	for (i = 0; i < [components count]; i++)
 	{
@@ -169,7 +183,6 @@
 	}
 	
 	NSString *extension = [[NSString stringWithString:@"."] stringByAppendingString:[[track codecString] lowercaseString]];
-	NSString *fullPath = [directory stringByAppendingString:filename];
 	
 	fullPath = [fullPath stringByAppendingString:extension];
 	
@@ -190,7 +203,7 @@
 	[copyTrack setStatus:STATUS_DOWNLOADING_TRACK];
 	NSString *description = [NSString stringWithFormat:NSLocalizedString(@"Downloading track '%@'", nil), [track title]];
 	
-	// could update browser here, but causes browser to lose selection so annoying
+	NSMutableArray *tasks = [[NSMutableArray alloc] initWithCapacity:2];
 	
 	// write track tag to file
 	if ([preferences writeTagAfterCopy] && [track codec] == CODEC_MP3)
@@ -198,14 +211,27 @@
 		NJBQueueItem *writeTag = [[NJBQueueItem alloc] initWithTarget:self withSelector:@selector(writeTagToFile:) withObject:track];
 		[writeTag setRunInMainThread:YES];
 		[writeTag setDisplayStatus:NO];
-
-		[self addToQueue:copyTrack withSubItems:[NSArray arrayWithObjects:writeTag, nil] withDescription:description];
+		
+		[tasks addObject:writeTag];
+		
 		[writeTag release];
 	}
-	else
-		[self addToQueue:copyTrack withSubItems:nil withDescription:description];
+	
+	if ([preferences iTunesIntegration])
+	{
+		NJBQueueItem *addToiTunes = [[NJBQueueItem alloc] initWithTarget:self withSelector:@selector(addTrackToiTunes:) withObject:track];
+		[addToiTunes setRunInMainThread:YES];
+		[addToiTunes setDisplayStatus:NO];
+		
+		[tasks addObject:addToiTunes];
+		
+		[addToiTunes release];
+	}
+	
+	[self addToQueue:copyTrack withSubItems:tasks withDescription:description];
 	
 	[copyTrack release];
+	[tasks release];
 }
 
 /* copy the file at filename to
@@ -269,9 +295,13 @@
  */
 - (void)tableViewSelectionDidChange:(NSNotification *)aNotification
 {
-	// we might be called from code changing the selection
+	// we might be called from code changing the selection but still update the
+	// item count anyway since it could be the iTunes table
 	if (activeObject != OBJECT_NJB_TABLE)
+	{
+		[self showItemCounts];
 		return;
+	}
 	[super tableViewSelectionDidChange:aNotification];
 	// unchanged tag edit will be lost
 	
@@ -509,4 +539,152 @@
 	}
 }
 
+- (void)loadiTunesLibrary
+{
+	[iTunesArrayController removeAll];
+	
+	NSString *iTunesLibrary = @"~/Music/iTunes/iTunes Music Library.xml";
+	iTunesLibrary = [iTunesLibrary stringByExpandingTildeInPath];
+	NSDictionary *iTunesDict = [NSDictionary dictionaryWithContentsOfFile:iTunesLibrary];
+	
+	// if we made an error loading it then give up and say we're not using iTunes
+	if (iTunesDict == nil)
+	{
+		NSRunAlertPanel(NSLocalizedString(@"iTunes Library", nil), 
+										[NSString stringWithFormat:@"%@ '%@'", NSLocalizedString(@"Could not load iTunes library from", nil), iTunesLibrary],
+										NSLocalizedString(@"OK", nil),
+										nil, nil);
+		return;
+	}
+	
+	NSDictionary *tracksDict = [iTunesDict objectForKey:@"Tracks"];
+	
+	NSDictionary *thisTrackDict;
+	NSArray *tracksDictArray = [tracksDict allValues];
+	NSEnumerator *objectEnumerator = [tracksDictArray objectEnumerator];
+	while (thisTrackDict = [objectEnumerator nextObject])
+	{
+		NSString *codec = [thisTrackDict objectForKey:@"Kind"];
+		 
+		// we can only work with MP3 files from iTunes so ignore others
+		if (codec != nil && ([codec isEqualToString:@"MPEG audio file"] || [codec isEqualToString:@"WAV audio file"] || [codec isEqualToString:@"Fichier audio WAV"]))
+		{
+			Track *track = [[Track alloc] init];
+		
+			[track setTitle:[thisTrackDict valueForKey:@"Name"]];
+			[track setAlbum:[thisTrackDict valueForKey:@"Album"]];
+			[track setArtist:[thisTrackDict valueForKey:@"Artist"]];
+			[track setGenre:[thisTrackDict valueForKey:@"Genre"]];
+			[track setFullPath:[[NSURL URLWithString:[thisTrackDict valueForKey:@"Location"]] relativePath]];
+			[track setLength:([[thisTrackDict valueForKey:@"Total Time"] unsignedLongValue] / 1000)];
+			[track setYear:[[thisTrackDict valueForKey:@"Year"] unsignedIntValue]];
+			[track setTrackNumber:[[thisTrackDict valueForKey:@"Track Number"] unsignedIntValue]];
+			[track setFilesize:[[thisTrackDict valueForKey:@"Size"] unsignedLongLongValue]];
+			[track setCodec:CODEC_MP3];
+			
+			[iTunesArrayController addObject:track];
+			[track release];
+		}
+	}
+	[self showItemCounts];
+}
+
+/* get a list of all the files to copy to the NJB
+ */
+- (IBAction)copyToNJB:(id)sender
+{
+	if (![preferences iTunesIntegration])
+		return [super copyToNJB:sender];
+	
+	NSArray *filesToCopy = [iTunesArrayController selectedObjects];
+	Track *currentTrack;
+	NSEnumerator *enumerator = [filesToCopy objectEnumerator];
+	while (currentTrack = [enumerator nextObject])
+	{
+		[self copyTrackToNJB:currentTrack];
+	}
+	
+	// TODO: we will reread the track info from the ID3 tag rather than use iTunes tags
+}
+
+- (void)addTrackToiTunes:(Track *)track
+{
+	// iTunes only supports MP3 and WAV that we have support for
+	if ([track codec] != CODEC_MP3 && [track codec] != CODEC_WAV)
+		return;
+	
+	NSString *code = [NSString stringWithFormat:@" \
+	set filenameP to \"%@\"									\n \
+	set filenameAS to POSIX file filenameP	\n \
+	tell application \"iTunes\"							\n \
+		launch																\n \
+		set this_track to add filenameAS to playlist \"Library\" of source \"Library\" \n \
+	end tell" \
+		, [track fullPath]];
+	
+	NSAppleScript *appleScript = [[NSAppleScript alloc] initWithSource:code];
+	NSDictionary *errorInfo;
+	
+	if (![appleScript compileAndReturnError:&errorInfo])
+	{
+		NSLog(@"Could not compile AppleScipt!  Code:\n%@\n\n, errorinfo: %@", code, [errorInfo description]);
+	}
+	
+	if ([appleScript executeAndReturnError:&errorInfo] == nil)
+	{
+		NSLog(@"Could not execute AppleScipt!  Code:\n%@\n\n, errorinfo: %@", code, [errorInfo description]);
+	}
+	
+	[appleScript release];
+	
+	// add it to the list
+	[iTunesArrayController addObject:track];
+	[self showItemCounts];
+}
+
+/* delegate method called when
+ * the search box is modified
+ */
+- (IBAction)searchiTunesTableAction:(id)sender
+{
+	// iTunesSearchField has been changed
+	[iTunesArrayController search:sender];
+	
+	[self showItemCounts];
+}
+
+- (void)showItemCounts
+{
+	if ([preferences iTunesIntegration])
+	{
+		NSString *selectedString = [NSString stringWithFormat:NSLocalizedString(@"Selected %d out of %d", nil), [iTunesTable numberOfSelectedRows], [[iTunesArrayController arrangedObjects] count]];
+		[iTunesItemCountField setStringValue:selectedString];
+	}
+	
+	[super showItemCounts];
+}
+
+/* sets the view with iTunes table or file browser
+ * depending on settings
+ */
+- (void)setCorrectView
+{
+	if ([preferences iTunesIntegration])
+	{
+		[iTunesBox setHidden:NO];
+		[iTunesSearchField setHidden:NO];
+		[iTunesItemCountField setHidden:NO];
+		[fileBrowser setHidden:YES];
+		
+		[self loadiTunesLibrary];
+	}
+	else
+	{
+		[iTunesBox setHidden:YES];
+		[iTunesSearchField setHidden:YES];
+		[iTunesItemCountField setHidden:YES];
+		[fileBrowser setHidden:NO];
+	}
+}
+
 @end
\ No newline at end of file
