@@ -16,6 +16,11 @@
 
 #include "mtp-utils.h"
 
+#define MUSIC_ASSOC 0x0058
+#define PLAYLISTS_ASSOC 0x005c
+#define PICTURES_ASSOC 0x0068
+#define VIDEO_ASSOC 0x006c
+
 @interface NJB : NSObject {
 	IBOutlet StatusDisplayer *statusDisplayer;
 	njb_t *njb;
