@@ -692,7 +692,7 @@ StatusDisplayer *statusDisplayerGlobal;
 		}
 		
 		if (send_file(&params, [[track fullPath] fileSystemRepresentation], [[[track fullPath] lastPathComponent] fileSystemRepresentation],
-									format, &progressPTP, &handle) != PTP_RC_OK)
+									format, &progressPTP, &handle, MUSIC_ASSOC) != PTP_RC_OK)
 		{
 			NSString *error = @"Error uploading file";
 			NSLog(error);
@@ -1001,6 +1001,7 @@ StatusDisplayer *statusDisplayerGlobal;
 			}
 		}
 		int i = 0;
+	
 		for (i = 0; i < params.handles.n; i++) {
 			if (ptp_getobjectinfo(&params,params.handles.Handler[i], &oi) == PTP_RC_OK)
 			{
@@ -1089,36 +1090,71 @@ StatusDisplayer *statusDisplayerGlobal;
 	{
 		uint16_t objectFormat = PTP_OFC_Undefined;
 		
+		uint32_t parenthandle = 0;
+		
 		// a test to see how the player works with video & images
 		NSString *extension = [[[dataFile fullPath] pathExtension] lowercaseString];
 		if ([extension isEqualToString:@"wmv"])
+		{
 			objectFormat = PTP_OFC_WMV;
+			parenthandle = VIDEO_ASSOC;
+		}
 		else if ([extension isEqualToString:@"avi"])
+		{
 			objectFormat = PTP_OFC_AVI;
+			parenthandle = VIDEO_ASSOC;
+		}
 		else if ([extension isEqualToString:@"mpg"] || [extension isEqualToString:@"mpeg"])
+		{
 			objectFormat = PTP_OFC_MPEG;
+			parenthandle = VIDEO_ASSOC;
+		}
 		else if ([extension isEqualToString:@"asf"])
+		{
 			objectFormat = PTP_OFC_ASF;
+			parenthandle = VIDEO_ASSOC;
+		}
 		else if ([extension isEqualToString:@"qt"])
+		{
 			objectFormat = PTP_OFC_QT;
+			parenthandle = VIDEO_ASSOC;
+		}
 		else if ([extension isEqualToString:@"jpg"] || [extension isEqualToString:@"jpeg"])
+		{
 			objectFormat = PTP_OFC_EXIF_JPEG;
+			parenthandle = PICTURES_ASSOC;
+		}
 		else if ([extension isEqualToString:@"tif"] || [extension isEqualToString:@"tiff"])
+		{
 			objectFormat = PTP_OFC_TIFF;
+			parenthandle = PICTURES_ASSOC;
+		}
 		else if ([extension isEqualToString:@"bmp"])
+		{
 			objectFormat = PTP_OFC_BMP;
+			parenthandle = PICTURES_ASSOC;
+		}
 		else if ([extension isEqualToString:@"gif"])
+		{
 			objectFormat = PTP_OFC_GIF;
+			parenthandle = PICTURES_ASSOC;
+		}
 		else if ([extension isEqualToString:@"pict"])
+		{
 			objectFormat = PTP_OFC_PICT;
+			parenthandle = PICTURES_ASSOC;
+		}
 		else if ([extension isEqualToString:@"png"])
+		{
 			objectFormat = PTP_OFC_PNG;
+			parenthandle = PICTURES_ASSOC;
+		}
 		
 		NSLog(@"uploading file with object format 0x%.02x", objectFormat);
 		
 		uint32_t handle = 0;
 		uint16_t ret = send_file(&params, [[dataFile fullPath] fileSystemRepresentation], [[[dataFile fullPath] lastPathComponent] fileSystemRepresentation],
-														 objectFormat, &progressPTP, &handle);
+														 objectFormat, &progressPTP, &handle, parenthandle);
 		if (ret != PTP_RC_OK)
 		{
 			/* we might get an (MTP error) object too large here */
@@ -1467,7 +1503,7 @@ StatusDisplayer *statusDisplayerGlobal;
 			newInfo.ObjectCompressedSize = 1;
 			
 			uint32_t store = 0;
-			uint32_t parenthandle = 0;
+			uint32_t parenthandle = 0; // don't set to PLAYLISTS_ASSOC yet since we have to check it exists first as sendobjectinfo fails if doesn't
 			
 			ret = ptp_sendobjectinfo(&params, &store, &parenthandle, &playlistID, &newInfo);
 			if (ret != PTP_RC_OK)
