@@ -55,5 +55,9 @@
 - (void)setArtistTol:(int)artistTol;
 - (BOOL)turbo;
 - (void)setTurbo:(BOOL)turbo;
+- (BOOL)iTunesIntegration;
+- (void)setiTunesIntegration:(BOOL)iTunesIntegration;
+- (NSString *)downloadDir;
+- (void)setDownloadDir:(NSString *)downloadDir;
 
 @end
