@@ -226,6 +226,26 @@
 	[theNJB setTurbo:turbo];
 }
 
+- (BOOL)iTunesIntegration
+{
+	return [defaults boolForKey:PREF_KEY_ITUNES_INTEGRATION];
+}
+
+- (void)setiTunesIntegration:(BOOL)iTunesIntegration
+{
+	[defaults setObject:[NSNumber numberWithBool:iTunesIntegration] forKey:PREF_KEY_ITUNES_INTEGRATION];
+}
+
+- (NSString *)downloadDir
+{
+	return [defaults objectForKey:PREF_KEY_DOWNLOAD_DIR];
+}
+
+- (void)setDownloadDir:(NSString *)downloadDir
+{
+	[defaults setObject:downloadDir forKey:PREF_KEY_DOWNLOAD_DIR];
+}
+
 /**********************/
 
 - (void)registerDefaults
@@ -268,6 +288,10 @@
 	[defaultValues setObject:DEFAULT_DUPLICATES_ARTIST_TOL forKey:PREF_KEY_DUPLICATES_ARTIST_TOL];
 	// TURBO
 	[defaultValues setObject:DEFAULT_TURBO forKey:PREF_KEY_TURBO];
+	// ITUNES_INTEGRATION
+	[defaultValues setObject:DEFAULT_PREF_KEY_ITUNES_INTEGRATION forKey:PREF_KEY_ITUNES_INTEGRATION];
+	// DOWNLOAD_DIR
+	[defaultValues setObject:DEFAULT_PREF_KEY_DOWNLOAD_DIR forKey:PREF_KEY_DOWNLOAD_DIR];
 	
 	[defaults registerDefaults:defaultValues];
 }
